==> CIO-DAS16-M1.1.3.2.tgz: das16-M1/das16-M1.h <==
/*
 * Copyright (C) 1997  Warren Jasper
 * All rights reserved.
 *
 * This software may be freely copied, modified, and redistributed
 * provided that this copyright notice is preserved on all copies.
 *
 * You may not distribute this software, in whole or in part, as part of
 * any commercial product without the express consent of the authors.
 *
 * There is no warranty or other guarantee of fitness of this software
 * for any purpose.  It is provided solely "as is".
 *
 */

/*
 * das16-M1.h
 */

/*  ioctl() values */

#define ADC_SET_GAINS       1
#define ADC_GET_GAINS       2
#define ADC_UPDATE_QUEUE    3
#define ADC_SET_PACER_FREQ  4
#define ADC_GET_PACER_FREQ  5
#define ADC_STOP_PACER      6
#define ADC_CTR0            7
#define ADC_COUNTER0        8
#define ADC_DIO_PRESET      9
#define ADC_PRETRIG         10
#define ADC_GET_STATUS      11
#define ADC_GET_DIO_VALUE   12
#define ADC_SET_DIO_VALUE   13
#define DIO_SET_MODE        14
#define DIO_SET_DIRECTION   15



/* open mode values */

#define ADC_SOFT_TRIGGER         (0x0)
#define ADC_EXTERNAL_PACER       (0x2)
#define ADC_PACER_CLOCK          (0x4)
#define ADC_PACER_EXTERN_TRIG    (0x6)

/* Digital I/O Modes */
#define MODE_IO            0
#define MODE_STROBE_IO     1
#define MODE_BIDIRECTIONAL 2

/* Digital I/O Direction Settings */
#define PORT_INPUT         1
#define PORT_OUTPUT        0
#define HIGH_PORT_INPUT    2
#define HIGH_PORT_OUTPUT   3
#define LOW_PORT_INPUT     4
#define LOW_PORT_OUTPUT    5


/* ioctl(COUNTER0) mode values */

#define CTR0_MODE0 (0x0 << 17)
#define CTR0_MODE1 (0x1 << 17)
#define CTR0_MODE2 (0x2 << 17)
#define CTR0_MODE3 (0x3 << 17)
#define CTR0_MODE4 (0x4 << 17)
#define CTR0_MODE5 (0x5 << 17)
#define CTR0_NOLOAD (0xff000000)

/*  General definitions */

#define MAX_FREQ 1000000
#define BYTE unsigned char
#define WORD unsigned short
#define LONG unsigned long

/* Programmable Range and Gain Settings */

#define BP_10_00V  0x08           /* +/- 10V      */
#define BP_5_00V   0x00           /* +/-  5V      */
#define BP_2_50V   0x01           /* +/-  2.5V    */
#define BP_1_25V   0x02           /* +/-  1.25V   */
#define BP_0_625V  0x03           /* +/-  0.625V  */
#define UP_10_00V  0x04           /* 0 - 10V      */
#define UP_5_00V   0x05           /* 0 - 5V       */
#define UP_2_50V   0x06           /* 0 - 2.5V     */
#define UP_1_25V   0x07           /* 0 - 1.25V    */

/* digital output */
#define DIO_0 0x1
#define DIO_1 0x2
#define DIO_2 0x4
#define DIO_3 0x8

==> CIO-DAS16-M1.1.4.tgz: das16-M1/das16-M1.h <==
/*
 * Copyright (C) 1997  Warren Jasper
 * All rights reserved.
 *
 */

/*
 * das16-M1.h
 */


#include <linux/ioctl.h>
#define IOCTL_MAGIC 'w'

/*  ioctl() values */

#define ADC_SET_GAINS       _IO(IOCTL_MAGIC,  1)
#define ADC_GET_GAINS       _IOR(IOCTL_MAGIC, 2, 4)
#define ADC_UPDATE_QUEUE    _IO(IOCTL_MAGIC,  3)
#define ADC_SET_PACER_FREQ  _IO(IOCTL_MAGIC,  4)
#define ADC_GET_PACER_FREQ  _IOR(IOCTL_MAGIC, 5, 4)
#define ADC_STOP_PACER      _IO(IOCTL_MAGIC,  6)
#define ADC_CTR0            _IO(IOCTL_MAGIC,  7)
#define ADC_COUNTER0        _IO(IOCTL_MAGIC,  8)
#define ADC_DIO_PRESET      _IO(IOCTL_MAGIC,  9)
#define ADC_PRETRIG         _IO(IOCTL_MAGIC, 10)
#define ADC_GET_STATUS      _IO(IOCTL_MAGIC, 11)
#define ADC_GET_DIO_VALUE   _IOR(IOCTL_MAGIC,12, 4)
#define ADC_SET_DIO_VALUE   _IO(IOCTL_MAGIC, 13)
#define DIO_SET_MODE        _IO(IOCTL_MAGIC, 14)
#define DIO_SET_DIRECTION   _IO(IOCTL_MAGIC, 15)

#define IOCTL_MAXNR 15         /* maxinum ordinal number */

/* open mode values */

#define ADC_SOFT_TRIGGER         (0x0)
#define ADC_EXTERNAL_PACER       (0x2)
#define ADC_PACER_CLOCK          (0x4)
#define ADC_PACER_EXTERN_TRIG    (0x6)

/* Digital I/O Modes */
#define MODE_IO            0
#define MODE_STROBE_IO     1
#define MODE_BIDIRECTIONAL 2

/* Digital I/O Direction Settings */
#define PORT_INPUT         1
#define PORT_OUTPUT        0
#define HIGH_PORT_INPUT    2
#define HIGH_PORT_OUTPUT   3
#define LOW_PORT_INPUT     4
#define LOW_PORT_OUTPUT    5


/* ioctl(COUNTER0) mode values */

#define CTR0_MODE0 (0x0 << 17)
#define CTR0_MODE1 (0x1 << 17)
#define CTR0_MODE2 (0x2 << 17)
#define CTR0_MODE3 (0x3 << 17)
#define CTR0_MODE4 (0x4 << 17)
#define CTR0_MODE5 (0x5 << 17)
#define CTR0_NOLOAD (0xff000000)

/*  General definitions */

#define MAX_FREQ 1000000
#define BYTE unsigned char
#define WORD unsigned short
#define LONG unsigned long

/* Programmable Range and Gain Settings */

#define BP_10_00V  0x08           /* +/- 10V      */
#define BP_5_00V   0x00           /* +/-  5V      */
#define BP_2_50V   0x01           /* +/-  2.5V    */
#define BP_1_25V   0x02           /* +/-  1.25V   */
#define BP_0_625V  0x03           /* +/-  0.625V  */
#define UP_10_00V  0x04           /* 0 - 10V      */
#define UP_5_00V   0x05           /* 0 - 5V       */
#define UP_2_50V   0x06           /* 0 - 2.5V     */
#define UP_1_25V   0x07           /* 0 - 1.25V    */

/* digital output */
#define DIO_0 0x1
#define DIO_1 0x2
#define DIO_2 0x4
#define DIO_3 0x8
